<?php

namespace Drupal\googlemap_block\Helper;

/**
 * Provide Helper Class for googlemap_block.
 */
class GoogleMapBlockHelper {

  const _MAPS_API = 'https://maps.googleapis.com/maps/api/geocode/json?address=';

  /**
   * Hold class object.
   *
   * @var object
   */
  private static $instance = NULL;

  /**
   * Hold Logger object.
   *
   * @var object
   */
  protected $logger;

  /**
   * Hold Database Connection object.
   *
   * @var object
   */
  public $database;

  /**
   * Hold Messenger Service object.
   *
   * @var object
   */
  public $messenger;

  /**
   * {@inheritdoc}
   */
  public function __construct() {
    $this->database = \Drupal::database();
    $this->logger = \Drupal::logger('googlemap_block');
    $this->messenger = \Drupal::messenger();
  }

  /**
   * Class instance.
   *
   * @staticvar object $inst
   *    Instance object.
   *
   * @return object
   *   Return instance.
   */
  public static function instance() {
    if (!isset(self::$instance)) {
      self::$instance = new GoogleMapBlockHelper();
    }
    return self::$instance;
  }

  /**
   * Return latitude and longitude.
   */
  public function getCordinates($address) {
    if (!empty($address)) {
      // Formatted address.
      $formattedAddr = str_replace(' ', '+', $address);
      // Send request and receive json data by address.
      $geocodeFromAddr = file_get_contents(self::_MAPS_API . urlencode($formattedAddr) . '&sensor=false');
      $output = json_decode($geocodeFromAddr);
      if ($output->status == 'OK') {
        // Get latitude and longitute from json data.
        $data['latitude'] = $output->results[0]->geometry->location->lat;
        $data['longitude'] = $output->results[0]->geometry->location->lng;
        // Return latitude and longitude of the given address.
        return $data;
      }
      elseif ($output->status == 'REQUEST_DENIED') {
        $this->logger->error("Please Check Your Google API Key Under Route- '/admin/structure/gmap-location/settings'");
        $this->logger->error($output->error_message);
        return FALSE;
      }
      else {
        $this->logger->error($output->error_message);
        return FALSE;
      }
    }
  }

}
